@@ -168,6 +168,8 @@ def p_value_method(x_mean, h0_mean, h0_std, samp_num, siglevel, option='left', p
         # two-tail test
         option = 'Two-Tail Test'
         p_value = (1 - stats.norm.cdf(z_value)) * 2
+        if (p_value > 1):
+            p_value = (stats.norm.cdf(z_value)) * 2
         zcv = stats.norm.ppf(1 - siglevel/2)
         flag = p_value < alpha
         sub_result = f'''Using {option}:
@@ -284,18 +286,19 @@ def sample_size(h0_mean, h1_mean, std, alpha, beta):
     return n
 
 
-def power_plot(h0_mean, psigma, nsizes, alpha, ranges, option='r', figsize=(12, 6)):
+def power_plot(h0_mean, psigma, nsizes, alpha, ranges, option='r', figsize=(12, 6), show=True):
     means, betas, xticks, yticks = type2_plot(
-        h0_mean, psigma, nsizes, alpha, ranges, option=option, figsize=figsize, pf=True, label=True)
-    plt.clf()
-    plt.plot(means, 1 - betas)
-    plt.xticks(xticks, rotation=45, fontsize=8)
-    plt.yticks(yticks, fontsize=8)
-    plt.title('Power Function Curve')
-    plt.margins(x=.01, tight=False)
+        h0_mean, psigma, nsizes, alpha, ranges, option=option, figsize=figsize, pf=True, label=True, show=show)
+    if show:
+        plt.clf()
+        plt.plot(means, 1 - betas)
+        plt.xticks(xticks, rotation=45, fontsize=8)
+        plt.yticks(yticks, fontsize=8)
+        plt.title('Power Function Curve')
+        plt.margins(x=.01, tight=False)
 
 
-def type2_plot(h0_mean, psigma, nsizes, alpha, ranges, option='right', figsize=(12, 6), pf=False, label=True):
+def type2_plot(h0_mean, psigma, nsizes, alpha, ranges, option='right', figsize=(12, 6), pf=False, label=True, show=True):
     # 外面要自己 plt.show()
 
     try:
@@ -316,7 +319,8 @@ def type2_plot(h0_mean, psigma, nsizes, alpha, ranges, option='right', figsize=(
     betas = np.zeros(means.shape[0])
     powers = betas.copy()
 
-    fig, ax = plt.subplots(figsize=figsize)
+    if show:
+        fig, ax = plt.subplots(figsize=figsize)
 
     for nsize in nsizes:
         means = np.arange(ranges[0], ranges[1], 0.1)
@@ -354,10 +358,12 @@ def type2_plot(h0_mean, psigma, nsizes, alpha, ranges, option='right', figsize=(
                 i += 1
 
         if pf:
-            plt.plot(means, betas, label=f'OC')
-            plt.plot(means, powers, label=f'PF')
+            if show:
+                plt.plot(means, betas, label=f'OC ({nsize})')
+                plt.plot(means, powers, label=f'PF ({nsize})')
         else:
-            plt.plot(means, betas, label=f'n = {nsize}')
+            if show:
+                plt.plot(means, betas, label=f'n = {nsize}')
 
     if len(ranges) == 3:
         xticks = np.arange(ranges[0], ranges[1] + 1, ranges[2])
@@ -365,13 +371,14 @@ def type2_plot(h0_mean, psigma, nsizes, alpha, ranges, option='right', figsize=(
         xticks = np.arange(ranges[0], ranges[1] + 1, 1)
     yticks = np.arange(0, 1.1, .1)
 
-    plt.xlabel("H1 Mean")
-    plt.xticks(xticks, rotation=45, fontsize=8)
-    plt.yticks(yticks, fontsize=8)
-    plt.ylabel("Probability of a Type II Error")
-    plt.margins(x=.01, tight=False)
-    if label:
-        plt.legend()
+    if show:
+        plt.xlabel("H1 Mean")
+        plt.xticks(xticks, rotation=45, fontsize=8)
+        plt.yticks(yticks, fontsize=8)
+        plt.ylabel("Probability of a Type II Error")
+        plt.margins(x=.01, tight=False)
+        if label:
+            plt.legend()
 
     if pf:
         return means, betas, xticks, yticks
