@@ -12,7 +12,10 @@ def samp_size(s_p, width, alpha):
     return (z_cv * math.sqrt(s_p * (1 - s_p)) / width) ** 2
 
 
-def con_level(s_p, n, alpha, show=True, Wilson=False, N=False):
+def con_level(s_p, n, alpha, show=True, Wilson=False, N=False, correction=True):
+    """
+    Caution: np̂ > 5 and n(1 - p̂) > 5
+    """
     con_coef = 1 - alpha
     z_cv = stats.norm.ppf(1 - alpha / 2)
     if not Wilson and not samp.check5(n, s_p):
@@ -27,7 +30,8 @@ def con_level(s_p, n, alpha, show=True, Wilson=False, N=False):
     ucl = s_p + lat
 
     if N:
-        if n / N > 0.5:
+        if n / N > 0.5 and correction:
+            print("Corrected...")
             fpcf = math.sqrt((N - n)/(N - 1))
             lcl = s_p - lat * fpcf
             ucl = s_p + lat * fpcf
